@@ -157,14 +157,17 @@ real_path (const gchar *path)
 static int
 get_line_for_text (const gchar *path, const gchar *msgid)
 {
+  GFile *file;
   gchar *content, *str_found, *i, *escaped;
   int result;
 
+  file = g_file_new_for_path (path);
+
   content = NULL;
   result = 1;
   escaped = g_markup_escape_text (msgid, -1);
 
-  if (!g_file_get_contents (path, &content, NULL, NULL))
+  if (!g_file_load_contents (file, NULL, &content, NULL, NULL, NULL))
     goto out;
 
   i = content;
@@ -205,6 +208,9 @@ follow_if_link (GtrCodeView *codeview, GtkWidget *text_view, GtkTextIter *iter)
       int line = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (tag), "line"));
       g_autofree char *fullpath = NULL;
 
+      if (!path)
+        continue;
+
       fullpath = find_source_file (codeview, path);
 
       if (fullpath && path_is_fake (fullpath))
