@@ -46,11 +46,13 @@
 #define GTR_TAB_SAVE_AS    "gtr-tab-save-as"
 #define GTR_IS_CLOSING_ALL "gtr-is-closing-all"
 
-#define API_URL "https://l10n.gnome.org/api/v1/"
-
 static void load_file_list (GtrWindow * window, const GSList * uris);
 static GList * get_modified_documents (GtrWindow * window);
 
+typedef struct {
+  SoupMessage *msg;
+  GtkWidget   *dialog;
+} UserData;
 
 /*
  * The main file opening function. Checks that the file isn't already open,
@@ -137,7 +139,7 @@ gtr_open (GFile * location, GtrWindow * window, GError ** error)
 }
 
 static void
-gtr_po_parse_files_from_dialog (GtkWidget * dialog, GtrWindow * window)
+gtr_po_parse_files_from_dialog (GtkNativeDialog * dialog, GtrWindow * window)
 {
   GSList *po_files, *l;
   GSList *locations = NULL;
@@ -173,25 +175,18 @@ gtr_po_parse_files_from_dialog (GtkWidget * dialog, GtrWindow * window)
    */
   load_file_list (window, (const GSList *) locations);
   g_slist_free_full (locations, g_object_unref);
-
-  /*
-   * Destroy the dialog 
-   */
-  gtk_widget_destroy (dialog);
 }
 
 
 static void
-gtr_file_chooser_analyse (gpointer dialog,
-                          FileselMode mode, GtrWindow * window)
+gtr_file_chooser_cb (GtkNativeDialog * dialog, guint reply, gpointer user_data)
 {
-  gint reply;
+  GtrWindow *window = GTR_WINDOW (user_data);
 
-  reply = gtk_native_dialog_run (GTK_NATIVE_DIALOG (dialog));
-  if (reply == GTK_RESPONSE_ACCEPT && mode == FILESEL_OPEN)
-    gtr_po_parse_files_from_dialog (GTK_WIDGET (dialog), window);
+  if (reply == GTK_RESPONSE_ACCEPT)
+    gtr_po_parse_files_from_dialog (dialog, window);
 
-  g_object_unref (dialog);
+  gtk_native_dialog_destroy (dialog);
 }
 
 gboolean
@@ -206,13 +201,15 @@ gtr_want_to_save_current_dialog (GtrWindow * window)
   g_autofree gchar *filename = NULL;
   g_autofree gchar *markup = NULL;
 
+  GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL;
+
   tab = gtr_window_get_active_tab (window);
   po = gtr_tab_get_po (tab);
   location = gtr_po_get_location (po);
   filename = g_file_get_path (location);
 
   dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+                                   flags,
                                    GTK_MESSAGE_WARNING,
                                    GTK_BUTTONS_NONE, NULL);
 
@@ -247,9 +244,9 @@ gtr_want_to_save_current_dialog (GtrWindow * window)
  * The "Open file" dialog.
  */
 void
-gtr_open_file_dialog (GtkAction * action, GtrWindow * window)
+gtr_open_file_dialog (GtrWindow * window)
 {
-  GtkWidget *dialog = NULL;
+  GtkNativeDialog *dialog;
   g_autoptr (GList) list = NULL;
   list = get_modified_documents (window);
   if (list != NULL)
@@ -263,11 +260,12 @@ gtr_open_file_dialog (GtkAction * action, GtrWindow * window)
                                  _("Open file for translation"),
                                  _gtr_application_get_last_dir (GTR_APP));
 
-  gtr_file_chooser_analyse ((gpointer) dialog, FILESEL_OPEN, window);
+  g_signal_connect (dialog, "response", G_CALLBACK (gtr_file_chooser_cb), window);
+  gtk_native_dialog_show (dialog);
 }
 
 static void
-save_dialog_response_cb (GtkDialog * dialog,
+save_dialog_response_cb (GtkNativeDialog * dialog,
                          gint response_id, GtrWindow * window)
 {
   GError *error = NULL;
@@ -276,7 +274,7 @@ save_dialog_response_cb (GtkDialog * dialog,
   gchar *filename;
   GFile *location;
 
-  tab = GTR_TAB (g_object_get_data (G_OBJECT (dialog), GTR_TAB_SAVE_AS));
+  tab = gtr_window_get_active_tab (window);
 
   g_return_if_fail (GTK_IS_FILE_CHOOSER (dialog));
 
@@ -284,7 +282,7 @@ save_dialog_response_cb (GtkDialog * dialog,
 
   if (response_id != GTK_RESPONSE_ACCEPT)
     {
-      g_object_unref (dialog);
+      gtk_native_dialog_destroy (dialog);
       return;
     }
 
@@ -294,7 +292,7 @@ save_dialog_response_cb (GtkDialog * dialog,
   location = g_file_new_for_path (filename);
   g_free (filename);
 
-  g_object_unref (dialog);
+  gtk_native_dialog_destroy (dialog);
 
   if (po != NULL)
     {
@@ -307,13 +305,14 @@ save_dialog_response_cb (GtkDialog * dialog,
       if (error)
         {
           GtkWidget *dialog;
+          GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL;
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                           GTK_DIALOG_DESTROY_WITH_PARENT,
+                                           flags,
                                            GTK_MESSAGE_WARNING,
                                            GTK_BUTTONS_OK,
                                            "%s", error->message);
-          gtk_dialog_run (GTK_DIALOG (dialog));
-          gtk_widget_destroy (dialog);
+          g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+          gtk_window_present (GTK_WINDOW (dialog));
           g_clear_error (&error);
           return;
         }
@@ -321,46 +320,37 @@ save_dialog_response_cb (GtkDialog * dialog,
       /* We have to change the state of the tab */
       gtr_po_set_state (po, GTR_PO_STATE_SAVED);
     }
-  g_object_unref (location);
-}
-
-static GtkFileChooserConfirmation
-confirm_overwrite_callback (GtkFileChooser * dialog, gpointer data)
-{
-  gchar *uri;
-  GtkFileChooserConfirmation res;
-
-  uri = gtk_file_chooser_get_uri (dialog);
-
-  /*
-   * FIXME: We have to detect if the file is read-only
-   */
-
-  /* fall back to the default confirmation dialog */
-  res = GTK_FILE_CHOOSER_CONFIRMATION_CONFIRM;
-
-  g_free (uri);
-
-  return res;
+  else
+    {
+      g_object_unref (location);
+    }
 }
 
 static void
-_upload_file_callback (SoupSession *session,
-                       SoupMessage *msg,
-                       gpointer     user_data)
+_upload_file_callback (GObject      *object,
+                       GAsyncResult *result,
+                       gpointer      user_data)
 {
+  UserData *ud = user_data;
+  g_autoptr(GInputStream) stream = NULL;
   GtkWidget *dialog;
   GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL;
   GtrNotebook *active_notebook;
 
-  GtkWidget *upload_dialog = user_data;
+  GtkWidget *upload_dialog = ud->dialog;
   GtkWidget *window = gtr_upload_dialog_get_parent (GTR_UPLOAD_DIALOG (upload_dialog));
+  SoupSession *session = SOUP_SESSION (object);
+  SoupStatus status_code = soup_message_get_status (ud->msg);
+
+  GError *error = NULL;
+
+  stream = soup_session_send_finish (session, result, &error);
 
   active_notebook = gtr_window_get_notebook (GTR_WINDOW (window));
 
-  if (!SOUP_STATUS_IS_SUCCESSFUL (msg->status_code))
+  if (error || !SOUP_STATUS_IS_SUCCESSFUL (status_code))
     {
-      if (msg->status_code == 403)
+      if (status_code == SOUP_STATUS_FORBIDDEN)
         {
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                                            flags,
@@ -371,6 +361,18 @@ _upload_file_callback (SoupSession *session,
           goto end;
         }
 
+      g_autofree gchar *message = NULL;
+
+      if (error)
+        {
+          message = error->message;
+          g_clear_error (&error);
+        }
+      else
+        {
+          message = g_strdup (soup_status_get_phrase (status_code));
+        }
+
       dialog = gtk_message_dialog_new_with_markup (
         GTK_WINDOW (window),
         flags,
@@ -382,7 +384,7 @@ _upload_file_callback (SoupSession *session,
           "<b>token</b> correctly in your profile or you don't have "
           "permissions to upload this module."
         ),
-        soup_status_get_phrase (msg->status_code));
+        message);
       goto end;
     }
 
@@ -395,9 +397,10 @@ _upload_file_callback (SoupSession *session,
   gtr_notebook_enable_upload (active_notebook, FALSE);
 
 end:
-  gtk_dialog_run (GTK_DIALOG (dialog));
-  gtk_widget_destroy (dialog);
+  g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+  gtk_window_present (GTK_WINDOW (dialog));
   gtk_widget_destroy (upload_dialog);
+  g_free (ud);
 }
 
 void
@@ -407,18 +410,17 @@ gtr_upload_file (GtkWidget *upload_dialog,
 {
   GtrTab *tab;
   GtrPo *po;
-  GMappedFile *mapped;
+  GBytes *bytes;
   GError *error = NULL;
   GtrProfileManager *pmanager = NULL;
   GtrProfile *profile;
   GtrHeader *header;
   g_autoptr (SoupMultipart) mpart = NULL;
-  g_autoptr (SoupBuffer) buffer = NULL;
 
   SoupMessage *msg = NULL;
   static SoupSession *session = NULL;
 
-  const gchar *content = NULL;
+  g_autofree gchar *content = NULL;
   g_autofree gchar *mime_type = NULL;
   g_autofree gchar *filename = NULL;
   g_autofree gchar *upload_endpoint = NULL;
@@ -444,17 +446,18 @@ gtr_upload_file (GtkWidget *upload_dialog,
   /* Get file content */
   tab = gtr_window_get_active_tab (window);
   po = gtr_tab_get_po (tab);
-  filename = g_file_get_path (gtr_po_get_location (po));
-  mapped = g_mapped_file_new (filename, FALSE, &error);
+  filename = g_file_get_basename (gtr_po_get_location (po));
+  g_file_load_contents (gtr_po_get_location (po), NULL, &content, &size, NULL,
+                        &error);
   if (error != NULL) {
     g_warning ("Error opening file %s: %s", filename, (error)->message);
+    g_error_free (error);
   }
-  content = g_mapped_file_get_contents (mapped);
-  size = g_mapped_file_get_length (mapped);
+  bytes = g_bytes_new (content, size);
   header = gtr_po_get_header (po);
 
   /* Check mimetype */
-  mime_type = g_strdup (g_content_type_get_mime_type(content));
+  mime_type = g_content_type_guess (filename, (const guchar *) content, size, NULL);
 
   /* Get the authentication token from the user profile */
   pmanager = gtr_profile_manager_get_default ();
@@ -488,25 +491,29 @@ gtr_upload_file (GtkWidget *upload_dialog,
 
   /* Init multipart container */
   mpart = soup_multipart_new (SOUP_FORM_MIME_TYPE_MULTIPART);
-  buffer = soup_buffer_new (SOUP_MEMORY_COPY, content, size);
-  soup_multipart_append_form_file (mpart, "file", filename,
-                                   mime_type, buffer);
+  soup_multipart_append_form_file (mpart, "file", filename, mime_type, bytes);
+  g_bytes_unref (bytes);
   if (upload_comment)
     soup_multipart_append_form_string (mpart, "comment", upload_comment);
 
   /* Get the associated message */
-  msg = soup_form_request_new_from_multipart (upload_endpoint, mpart);
+  msg = soup_message_new_from_multipart (upload_endpoint, mpart);
   soup_message_set_flags (msg, SOUP_MESSAGE_NO_REDIRECT);
 
   /* Append the authentication header*/
-  soup_message_headers_append (msg->request_headers, "Authentication", auth);
+  soup_message_headers_append (soup_message_get_request_headers (msg),
+                               "Authentication", auth);
 
   gtr_upload_dialog_set_loading (GTR_UPLOAD_DIALOG (upload_dialog), TRUE);
 
   if (!session)
     session = soup_session_new ();
 
-  soup_session_queue_message (session, msg, _upload_file_callback, upload_dialog);
+  UserData *ud;
+  ud = g_new0 (UserData, 1);
+  ud->dialog = upload_dialog;
+  ud->msg = msg;
+  soup_session_send_async (session, msg, G_PRIORITY_DEFAULT, NULL, _upload_file_callback, ud);
 }
 
 /*
@@ -514,7 +521,7 @@ gtr_upload_file (GtkWidget *upload_dialog,
  *
  */
 void
-gtr_upload_file_dialog (GtkAction * action, GtrWindow * window)
+gtr_upload_file_dialog (GtrWindow * window)
 {
   GtrUploadDialog *dialog = gtr_upload_dialog_new (GTK_WIDGET (window));
 
@@ -530,35 +537,18 @@ gtr_upload_file_dialog (GtkAction * action, GtrWindow * window)
  * "Save as" dialog.
  */
 void
-gtr_save_file_as_dialog (GtkAction * action, GtrWindow * window)
+gtr_save_file_as_dialog (GtrWindow * window)
 {
-  GtkWidget *dialog = NULL;
-  GtrTab *current_page;
-  gint reply = 0;
+  GtkNativeDialog *dialog;
 
-  if (dialog != NULL)
-    {
-      gtk_window_present (GTK_WINDOW (dialog));
-      return;
-    }
-
-  current_page = gtr_window_get_active_tab (window);
   dialog = gtr_file_chooser_new (GTK_WINDOW (window),
                                  FILESEL_SAVE,
                                  _("Save file as…"),
                                  g_get_home_dir ());
 
-  gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog),
-                                                  TRUE);
-  g_signal_connect (dialog,
-                    "confirm-overwrite",
-                    G_CALLBACK (confirm_overwrite_callback), NULL);
-
-  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-  g_object_set_data (G_OBJECT (dialog), GTR_TAB_SAVE_AS, current_page);
-
-  reply = gtk_native_dialog_run (GTK_NATIVE_DIALOG (dialog));
-  save_dialog_response_cb (GTK_DIALOG (dialog), reply, window);
+  g_signal_connect (dialog, "response", G_CALLBACK (save_dialog_response_cb),
+                    window);
+  gtk_native_dialog_show (dialog);
 }
 
 /*
@@ -579,12 +569,13 @@ gtr_save_current_file_dialog (GtkWidget * widget, GtrWindow * window)
   if (error)
     {
       GtkWidget *dialog;
+      GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL;
       dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                       GTK_DIALOG_DESTROY_WITH_PARENT,
+                                       flags,
                                        GTK_MESSAGE_WARNING,
                                        GTK_BUTTONS_OK, "%s", error->message);
-      gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
+      g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+      gtk_window_present (GTK_WINDOW (dialog));
       g_clear_error (&error);
       return;
     }
@@ -668,16 +659,17 @@ load_file_list (GtrWindow * window, const GSList * locations)
   if (error != NULL)
     {
       GtkWidget *dialog;
+      GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL;
       /*
        * We have to show the error in a dialog
        */
       dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                       GTK_DIALOG_DESTROY_WITH_PARENT,
+                                       flags,
                                        GTK_MESSAGE_ERROR,
                                        GTK_BUTTONS_CLOSE,
                                        "%s", error->message);
-      gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
+      g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+      gtk_window_present (GTK_WINDOW (dialog));
       g_error_free (error);
     }
 
@@ -738,13 +730,14 @@ save_and_close_all_documents (GList * unsaved_documents, GtrWindow * window)
       if (error)
         {
           GtkWidget *dialog;
+          GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL;
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                           GTK_DIALOG_DESTROY_WITH_PARENT,
+                                           flags,
                                            GTK_MESSAGE_WARNING,
                                            GTK_BUTTONS_OK,
                                            "%s", error->message);
-          gtk_dialog_run (GTK_DIALOG (dialog));
-          gtk_widget_destroy (dialog);
+          g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+          gtk_window_present (GTK_WINDOW (dialog));
           g_clear_error (&error);
 
           return;
@@ -862,7 +855,7 @@ gtr_close_tab (GtrTab * tab, GtrWindow * window)
 }
 
 void
-gtr_file_close (GtkAction * widget, GtrWindow * window)
+gtr_file_close (GtrWindow * window)
 {
   GtrTab *tab;
 
@@ -933,7 +926,7 @@ close_all_documents (GtrWindow * window, gboolean logout_mode)
 }
 
 void
-gtr_file_quit (GtkAction * action, GtrWindow * window)
+gtr_file_quit (GtrWindow * window)
 {
   g_object_set_data (G_OBJECT (window),
                      GTR_IS_CLOSING_ALL, GINT_TO_POINTER (1));
@@ -942,13 +935,13 @@ gtr_file_quit (GtkAction * action, GtrWindow * window)
 }
 
 void
-_gtr_actions_file_close_all (GtkAction * action, GtrWindow * window)
+_gtr_actions_file_close_all (GtrWindow * window)
 {
   close_all_documents (window, FALSE);
 }
 
 void
-_gtr_actions_file_save_all (GtkAction * action, GtrWindow * window)
+_gtr_actions_file_save_all (GtrWindow * window)
 {
   GList *list, *l;
 
@@ -963,14 +956,15 @@ _gtr_actions_file_save_all (GtkAction * action, GtrWindow * window)
       if (error)
         {
           GtkWidget *dialog;
+          GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL;
 
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                           GTK_DIALOG_DESTROY_WITH_PARENT,
+                                           flags,
                                            GTK_MESSAGE_WARNING,
                                            GTK_BUTTONS_OK,
                                            "%s", error->message);
-          gtk_dialog_run (GTK_DIALOG (dialog));
-          gtk_widget_destroy (dialog);
+          g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+          gtk_window_present (GTK_WINDOW (dialog));
           g_clear_error (&error);
 
           return;
