@@ -125,7 +125,7 @@ static gboolean
 on_window_delete_event_cb (GtrWindow * window,
                            GdkEvent * event, GtrApplication * app)
 {
-  gtr_file_quit (NULL, window);
+  gtr_file_quit (window);
   return TRUE;
 }
 
@@ -162,6 +162,15 @@ on_window_destroy_cb (GtrWindow *window, GtrApplication *app)
     set_active_window (app, windows != NULL ? windows->data : NULL);
 }
 
+static int
+handle_local_options_cb (GApplication *application, GVariantDict *options, gpointer user_data) {
+  if (g_variant_dict_contains (options, "version")) {
+    g_print ("%s - %s\n", PACKAGE, PACKAGE_VERSION);
+    return 0;
+  }
+  return -1;
+}
+
 static void
 gtr_application_init (GtrApplication *application)
 {
@@ -173,6 +182,15 @@ gtr_application_init (GtrApplication *application)
   priv->last_dir = NULL;
   priv->first_run = FALSE;
 
+  GOptionEntry options[] = {
+      {"version", 'v', 0, G_OPTION_ARG_NONE, NULL, "Print version information and exit", NULL},
+      {NULL}
+  };
+
+  g_application_add_main_option_entries (G_APPLICATION (application), options);
+
+  g_signal_connect (application, "handle-local-options", G_CALLBACK (handle_local_options_cb), NULL);
+
   /* Creating config folder */
   ensure_user_config_dir (); /* FIXME: is this really needed ? */
 
@@ -245,7 +263,7 @@ find_activated (GSimpleAction *action,
 
   GtrTab *active_tab = gtr_window_get_active_tab (priv->active_window);
   g_return_if_fail (active_tab != NULL);
-  gtr_window_show_search_bar (priv->active_window, TRUE);
+  gtr_window_show_focus_search_bar (priv->active_window, TRUE);
   gtr_tab_find_set_replace (active_tab, FALSE);
 }
 
@@ -259,7 +277,7 @@ find_next_activated (GSimpleAction *action,
 
   GtrTab *active_tab = gtr_window_get_active_tab (priv->active_window);
   g_return_if_fail (active_tab != NULL);
-  gtr_window_show_search_bar (priv->active_window, TRUE);
+  gtr_window_show_focus_search_bar (priv->active_window, TRUE);
   gtr_tab_find_next (active_tab);
 }
 
@@ -273,21 +291,10 @@ find_prev_activated (GSimpleAction *action,
 
   GtrTab *active_tab = gtr_window_get_active_tab (priv->active_window);
   g_return_if_fail (active_tab != NULL);
-  gtr_window_show_search_bar (priv->active_window, TRUE);
+  gtr_window_show_focus_search_bar (priv->active_window, TRUE);
   gtr_tab_find_prev (active_tab);
 }
 
-static void
-find_unactivated (GSimpleAction *action,
-                GVariant      *parameter,
-                gpointer       user_data)
-{
-  GtrApplication *app = GTR_APPLICATION (user_data);
-
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_window_show_search_bar (priv->active_window, FALSE);
-}
-
 static void
 find_and_replace_activated (GSimpleAction *action,
                             GVariant      *parameter,
@@ -297,7 +304,7 @@ find_and_replace_activated (GSimpleAction *action,
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
   GtrTab *active_tab = gtr_window_get_active_tab (priv->active_window);
-  gtr_window_show_search_bar (priv->active_window, TRUE);
+  gtr_window_show_focus_search_bar (priv->active_window, TRUE);
   gtr_tab_find_set_replace (active_tab, TRUE);
 }
 
@@ -309,7 +316,7 @@ copy_text_activated (GSimpleAction *action,
   GtrApplication *app = GTR_APPLICATION (user_data);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
-  gtr_message_copy_to_translation (NULL, priv->active_window);
+  gtr_message_copy_to_translation (priv->active_window);
 }
 
 static void
@@ -329,7 +336,17 @@ edit_header_activated (GSimpleAction *action,
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_actions_edit_header (NULL, priv->active_window);
+  gtr_actions_edit_header (priv->active_window);
+}
+
+static void
+clear_msgstr_activated (GSimpleAction *action,
+                        GVariant      *parameter,
+                        gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  gtr_actions_edit_clear (priv->active_window);
 }
 
 static void
@@ -399,11 +416,8 @@ quit_activated (GSimpleAction *action,
 
   for (l = windows; l != NULL; l = g_list_next (l))
     {
-      gtr_file_quit (NULL, l->data);
+      gtr_file_quit (l->data);
     }
-
-  // FIXME: we may want to continue editing
-  g_application_quit (G_APPLICATION (app));
 }
 
 static void
@@ -413,7 +427,7 @@ upload_file_activated (GSimpleAction *action,
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_upload_file_dialog (NULL, priv->active_window);
+  gtr_upload_file_dialog (priv->active_window);
 }
 
 static void
@@ -423,7 +437,7 @@ saveas_activated (GSimpleAction *action,
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_save_file_as_dialog (NULL, priv->active_window);
+  gtr_save_file_as_dialog (priv->active_window);
 }
 
 static void
@@ -443,7 +457,7 @@ open_activated (GSimpleAction *action,
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_open_file_dialog (NULL, priv->active_window);
+  gtr_open_file_dialog (priv->active_window);
 }
 
 static void
@@ -473,7 +487,7 @@ undo_activated (GSimpleAction *action,
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_actions_edit_undo (NULL, priv->active_window);
+  gtr_actions_edit_undo (priv->active_window);
 }
 
 static void
@@ -483,7 +497,7 @@ redo_activated (GSimpleAction *action,
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_actions_edit_redo (NULL, priv->active_window);
+  gtr_actions_edit_redo (priv->active_window);
 }
 
 static void
@@ -493,7 +507,7 @@ prev_activated (GSimpleAction *action,
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_message_go_to_previous (NULL, priv->active_window);
+  gtr_message_go_to_previous (priv->active_window);
 }
 
 static void
@@ -503,7 +517,7 @@ next_activated (GSimpleAction *action,
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_message_go_to_next (NULL, priv->active_window);
+  gtr_message_go_to_next (priv->active_window);
 }
 
 static void
@@ -513,7 +527,7 @@ prev_no_activated (GSimpleAction *action,
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_message_go_to_prev_fuzzy_or_untranslated (NULL, priv->active_window);
+  gtr_message_go_to_prev_fuzzy_or_untranslated (priv->active_window);
 }
 
 static void
@@ -523,7 +537,7 @@ next_no_activated (GSimpleAction *action,
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_message_go_to_next_fuzzy_or_untranslated (NULL, priv->active_window);
+  gtr_message_go_to_next_fuzzy_or_untranslated (priv->active_window);
 }
 
 static void
@@ -556,7 +570,7 @@ toggle_fuzzy_activated (GSimpleAction *action,
   GtrApplication *app = GTR_APPLICATION (user_data);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
   GtrWindow *w = GTR_WINDOW (priv->active_window);
-  gtr_message_status_toggle_fuzzy (NULL, w);
+  gtr_message_status_toggle_fuzzy (w);
 }
 
 static void
@@ -627,12 +641,12 @@ static GActionEntry app_entries[] = {
   { "find_and_replace", find_and_replace_activated, NULL, NULL, NULL },
   { "findtoggle", find_toggle_activated, NULL, NULL, NULL },
   { "find", find_activated, NULL, NULL, NULL },
-  { "find-off", find_unactivated, NULL, NULL, NULL},
   { "find-next", find_next_activated, NULL, NULL, NULL },
   { "find-prev", find_prev_activated, NULL, NULL, NULL },
   { "new_window", new_window_activated, NULL, NULL, NULL },
   { "preferences", preferences_activated, NULL, NULL, NULL },
   { "edit_header", edit_header_activated, NULL, NULL, NULL },
+  { "clear_msgstr", clear_msgstr_activated, NULL, NULL, NULL },
   { "shortcuts", shortcuts_activated, NULL, NULL, NULL },
   { "help", help_activated, NULL, NULL, NULL },
   { "about", about_activated, NULL, NULL, NULL },
@@ -649,7 +663,6 @@ set_kb (GApplication *app, gchar *action, gchar *accel)
 static void
 gtr_application_startup (GApplication *application)
 {
-  GtkBuilder *builder;
   GtrApplication *app = GTR_APPLICATION (application);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
@@ -665,6 +678,10 @@ gtr_application_startup (GApplication *application)
 
   load_accels ();
 
+  /* TODO Remove in GTK 4 port */
+  hdy_style_manager_set_color_scheme (hdy_style_manager_get_default (),
+                                      HDY_COLOR_SCHEME_PREFER_LIGHT);
+
   /* We set the default icon dir */
   gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
                                      gtr_dirs_get_gtr_pixmaps_dir ());
@@ -679,10 +696,12 @@ gtr_application_startup (GApplication *application)
   set_kb (application, "app.saveas", "<Ctrl><Shift>s");
   set_kb (application, "app.upload_file", "<Ctrl>b");
   set_kb (application, "app.preferences", "<Ctrl>p");
+  set_kb (application, "app.shortcuts", "<Ctrl><Shift>question");
   set_kb (application, "app.quit", "<Primary>q");
 
   set_kb (application, "app.undo", "<Ctrl>z");
   set_kb (application, "app.redo", "<Ctrl><Shift>z");
+  set_kb (application, "app.clear_msgstr", "<Ctrl>k");
 
   set_kb (application, "app.prev", "<Alt>Left");
   set_kb (application, "app.next", "<Alt>Right");
@@ -691,7 +710,6 @@ gtr_application_startup (GApplication *application)
 
   set_kb (application, "app.fuzzy", "<Ctrl>u");
   set_kb (application, "app.find", "<Ctrl>f");
-  set_kb (application, "app.find-off", "Escape");
   set_kb (application, "app.find_and_replace", "<Ctrl>h");
   set_kb (application, "app.find-next", "<Ctrl>g");
   set_kb (application, "app.find-prev", "<Ctrl><Shift>g");
@@ -709,12 +727,6 @@ gtr_application_startup (GApplication *application)
   set_kb (application, "app.tm_8", "<Ctrl>8");
   set_kb (application, "app.tm_9", "<Ctrl>9");
 
-  builder = gtk_builder_new ();
-  gtk_builder_add_from_resource (builder, "/org/gnome/translator/gtranslator-menu.ui", NULL);
-  gtk_application_set_app_menu (GTK_APPLICATION (application),
-                                G_MENU_MODEL (gtk_builder_get_object (builder, "appmenu")));
-  g_object_unref (builder);
-
   gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
                                              GTK_STYLE_PROVIDER (priv->provider), 600);
 }
