@@ -162,11 +162,15 @@ create_start_page (GtrAssistant * as)
 
   box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
   gtk_widget_show (box);
-  gtk_container_set_border_width (GTK_CONTAINER (box), 12);
+  gtk_widget_set_margin_start (box, 12);
+  gtk_widget_set_margin_end (box, 12);
+  gtk_widget_set_margin_top (box, 12);
+  gtk_widget_set_margin_bottom (box, 12);
 
   label = gtk_label_new (_("This assistant will help you to create the main profile."));
   gtk_widget_show (label);
-  gtk_box_pack_start (GTK_BOX (box), label, TRUE, TRUE, 0);
+  gtk_widget_set_hexpand (label, TRUE);
+  gtk_box_append (GTK_BOX (box), label);
 
   gtk_assistant_append_page (GTK_ASSISTANT (as), box);
   gtk_assistant_set_page_title (GTK_ASSISTANT (as), box, _("Assistant"));
@@ -245,14 +249,20 @@ create_profiles_page1 (GtrAssistant * as)
 
   box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
   gtk_widget_show (box);
-  gtk_container_set_border_width (GTK_CONTAINER (box), 5);
+  gtk_widget_set_margin_start (box, 6);
+  gtk_widget_set_margin_end (box, 6);
+  gtk_widget_set_margin_top (box, 6);
+  gtk_widget_set_margin_bottom (box, 6);
+
+  gtk_widget_set_valign (box, GTK_ALIGN_CENTER);
+  gtk_widget_set_halign (box, GTK_ALIGN_CENTER);
 
   /*
    * Profile name:
    */
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
   gtk_widget_show (hbox);
-  gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 0);
+  gtk_box_append (GTK_BOX (box), hbox);
 
   label = gtk_label_new (NULL);
   markup = g_strdup_printf("<b>%s</b>", _("Profile name"));
@@ -261,11 +271,12 @@ create_profiles_page1 (GtrAssistant * as)
   gtk_label_set_xalign (GTK_LABEL (label), 1.0);
   gtk_label_set_yalign (GTK_LABEL (label), 0.5);
   gtk_widget_show (label);
-  gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+  gtk_widget_set_hexpand (label, TRUE);
+  gtk_box_append (GTK_BOX (hbox), label);
 
   priv->profile_name = gtk_entry_new ();
   gtk_widget_show (priv->profile_name);
-  gtk_box_pack_start (GTK_BOX (hbox), priv->profile_name, FALSE, FALSE, 0);
+  gtk_box_append (GTK_BOX (hbox), priv->profile_name);
   g_signal_connect (G_OBJECT (priv->profile_name), "changed",
                     G_CALLBACK (on_profile1_entry_changed), as);
 
@@ -274,7 +285,7 @@ create_profiles_page1 (GtrAssistant * as)
    */
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
   gtk_widget_show (hbox);
-  gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 0);
+  gtk_box_append (GTK_BOX (box), hbox);
 
   label = gtk_label_new (NULL);
   markup = g_strdup_printf("<b>%s</b>", ("Translator name"));
@@ -283,11 +294,12 @@ create_profiles_page1 (GtrAssistant * as)
   gtk_label_set_xalign (GTK_LABEL (label), 1.0);
   gtk_label_set_yalign (GTK_LABEL (label), 0.5);
   gtk_widget_show (label);
-  gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+  gtk_widget_set_hexpand (label, TRUE);
+  gtk_box_append (GTK_BOX (hbox), label);
 
   priv->name = gtk_entry_new ();
   gtk_widget_show (priv->name);
-  gtk_box_pack_start (GTK_BOX (hbox), priv->name, FALSE, FALSE, 0);
+  gtk_box_append (GTK_BOX (hbox), priv->name);
   g_signal_connect (G_OBJECT (priv->name), "changed",
                     G_CALLBACK (on_profile1_entry_changed), as);
 
@@ -296,7 +308,7 @@ create_profiles_page1 (GtrAssistant * as)
    */
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
   gtk_widget_show (hbox);
-  gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 0);
+  gtk_box_append (GTK_BOX (box), hbox);
 
   label = gtk_label_new (NULL);
   markup = g_strdup_printf("<b>%s</b>", _("Translator email"));
@@ -305,11 +317,12 @@ create_profiles_page1 (GtrAssistant * as)
   gtk_label_set_xalign (GTK_LABEL (label), 1.0);
   gtk_label_set_yalign (GTK_LABEL (label), 0.5);
   gtk_widget_show (label);
-  gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+  gtk_widget_set_hexpand (label, TRUE);
+  gtk_box_append (GTK_BOX (hbox), label);
 
   priv->email = gtk_entry_new ();
   gtk_widget_show (priv->email);
-  gtk_box_pack_start (GTK_BOX (hbox), priv->email, FALSE, FALSE, 0);
+  gtk_box_append (GTK_BOX (hbox), priv->email);
   g_signal_connect (G_OBJECT (priv->email), "changed",
                     G_CALLBACK (on_profile1_entry_changed), as);
 
@@ -318,7 +331,7 @@ create_profiles_page1 (GtrAssistant * as)
    */
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
   gtk_widget_show (hbox);
-  gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 0);
+  gtk_box_append (GTK_BOX (box), hbox);
 
   label = gtk_label_new (NULL);
   markup = g_strdup_printf("<b>%s</b>", _("Team email"));
@@ -327,11 +340,12 @@ create_profiles_page1 (GtrAssistant * as)
   gtk_label_set_xalign (GTK_LABEL (label), 1.0);
   gtk_label_set_yalign (GTK_LABEL (label), 0.5);
   gtk_widget_show (label);
-  gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+  gtk_widget_set_hexpand (label, TRUE);
+  gtk_box_append (GTK_BOX (hbox), label);
 
   priv->team_email = gtk_entry_new ();
   gtk_widget_show (priv->team_email);
-  gtk_box_pack_start (GTK_BOX (hbox), priv->team_email, FALSE, FALSE, 0);
+  gtk_box_append (GTK_BOX (hbox), priv->team_email);
   g_signal_connect (G_OBJECT (priv->team_email), "changed",
                     G_CALLBACK (on_profile1_entry_changed), as);
 
@@ -420,7 +434,11 @@ create_profiles_page2 (GtrAssistant * as)
 
   priv->languages_fetcher = gtr_languages_fetcher_new ();
   gtk_widget_show (priv->languages_fetcher);
-  gtk_container_set_border_width (GTK_CONTAINER (priv->languages_fetcher), 5);
+  gtk_widget_set_margin_start (priv->languages_fetcher, 6);
+  gtk_widget_set_margin_end (priv->languages_fetcher, 6);
+  gtk_widget_set_margin_top (priv->languages_fetcher, 6);
+  gtk_widget_set_margin_bottom (priv->languages_fetcher, 6);
+
   g_signal_connect (priv->languages_fetcher, "changed",
                     G_CALLBACK (on_profile2_entry_changed),
                     as);
@@ -434,12 +452,13 @@ create_finish_page (GtrAssistant * as)
 {
   GtrAssistantPrivate *priv = gtr_assistant_get_instance_private (as);
   priv->finish_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+  gtk_widget_set_valign (priv->finish_box, GTK_ALIGN_CENTER);
   gtk_widget_show (priv->finish_box);
 
   priv->confirm_label = gtk_label_new (NULL);
   gtk_widget_show (priv->confirm_label);
-  gtk_box_pack_start (GTK_BOX (priv->finish_box), priv->confirm_label,
-                      TRUE, TRUE, 0);
+  gtk_widget_set_hexpand (priv->confirm_label, TRUE);
+  gtk_box_append (GTK_BOX (priv->finish_box), priv->confirm_label);
 
   gtk_assistant_append_page (GTK_ASSISTANT (as), priv->finish_box);
   gtk_assistant_set_page_type (GTK_ASSISTANT (as), priv->finish_box,
