@@ -22,6 +22,7 @@
 #include "gtr-context.h"
 #include "gtr-tab.h"
 #include "gtr-debug.h"
+#include "gtr-utils.h"
 #include "translation-memory/gtr-translation-memory-ui.h"
 
 #include <glib.h>
@@ -66,6 +67,24 @@ static guint signals[LAST_SIGNAL] = { 0 };
 static void buffer_end_user_action (GtkTextBuffer *buffer, GtrContextPanel *panel);
 static void reload_values (GtrContextPanel *panel);
 
+typedef struct {
+  GtrContextPanel *panel;
+  GtkTextBuffer   *text_buffer;
+} DialogData;
+
+static void
+dialog_response_cb (GtkDialog *dialog, guint response, gpointer user_data)
+{
+  DialogData *dd = user_data;
+
+  if (response == GTK_RESPONSE_ACCEPT)
+    buffer_end_user_action (dd->text_buffer, dd->panel);
+
+  gtk_widget_destroy (GTK_WIDGET (dialog));
+  reload_values (dd->panel);
+  g_free (dd);
+}
+
 static void
 setup_notes_edition (GtrContextPanel *panel)
 {
@@ -75,7 +94,7 @@ setup_notes_edition (GtrContextPanel *panel)
   GtkBox *dialog_area;
   GtkWidget *text_view;
   GtkTextBuffer *text_buffer = gtk_text_buffer_new (NULL);;
-  gint result;
+  DialogData *dd;
 
   priv = gtr_context_panel_get_instance_private (panel);
 
@@ -105,9 +124,13 @@ setup_notes_edition (GtrContextPanel *panel)
 
   gtk_container_add (GTK_CONTAINER (scrolled_window),
                                          text_view);
-  gtk_container_set_border_width (GTK_CONTAINER (scrolled_window), 5);
+  gtk_widget_set_margin_start (scrolled_window, 6);
+  gtk_widget_set_margin_end (scrolled_window, 6);
+  gtk_widget_set_margin_top (scrolled_window, 6);
+  gtk_widget_set_margin_bottom (scrolled_window, 6);
 
-  gtk_box_pack_start (dialog_area, scrolled_window, TRUE, TRUE, 6);
+  gtk_widget_set_vexpand (scrolled_window, TRUE);
+  gtk_box_append (dialog_area, scrolled_window);
 
   text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_view));
   gtk_text_buffer_set_text (text_buffer, gtr_msg_get_comment (priv->current_msg), -1);
@@ -116,20 +139,12 @@ setup_notes_edition (GtrContextPanel *panel)
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
   gtk_window_set_deletable (GTK_WINDOW (dialog), FALSE);
 
+  dd = g_new0 (DialogData, 1);
+  dd->panel = panel;
+  dd->text_buffer = text_buffer;
+
+  g_signal_connect (dialog, "response", G_CALLBACK (dialog_response_cb), dd);
   gtk_widget_show_all (dialog);
-  result = gtk_dialog_run (GTK_DIALOG (dialog));
-
-  switch (result)
-    {
-    case GTK_RESPONSE_ACCEPT:
-      buffer_end_user_action (text_buffer, panel);
-      break;
-    default:
-      break;
-    }
-
-  gtk_widget_destroy (dialog);
-  reload_values(panel);
 }
 
 static void
@@ -581,7 +596,6 @@ gtr_context_init_tm (GtrContextPanel *panel,
                                                                tm);
   gtk_widget_show (priv->translation_memory_ui);
   gtk_widget_set_size_request (priv->translation_memory_ui, 300, 400);
-  gtk_box_pack_start (GTK_BOX (priv->translation_memory_box),
-                      priv->translation_memory_ui,
-                      FALSE, FALSE, 0);
+  gtk_box_append (GTK_BOX (priv->translation_memory_box),
+                  priv->translation_memory_ui);
 }
