@@ -33,8 +33,6 @@
 
 #include <glib/gi18n.h>
 
-#define API_URL "https://l10n.gnome.org/api/v1/"
-
 typedef struct
 {
   GtkWidget *titlebar;
@@ -137,8 +135,8 @@ gtr_dl_teams_parse_teams_json (GObject *object,
                                              GTK_BUTTONS_CLOSE,
                                              "%s",
                                              error->message);
-      gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
+      g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+      gtk_window_present (GTK_WINDOW (dialog));
       return;
     }
 
@@ -177,6 +175,8 @@ gtr_dl_teams_load_module_details_json (GtkWidget  *widget,
   JsonNode *branchesNode;
   JsonNode *domainsNode;
   GtkWidget *dialog;
+  SoupStatus status_code;
+  g_autoptr(GInputStream) stream = NULL;
 
   gtk_widget_hide (priv->file_label);
   gtk_widget_hide (priv->module_state_label);
@@ -195,25 +195,38 @@ gtr_dl_teams_load_module_details_json (GtkWidget  *widget,
   module_endpoint = g_strconcat ((const gchar *)API_URL, "modules/", priv->selected_module, NULL);
   msg = soup_message_new ("GET", module_endpoint);
   session = soup_session_new ();
-  soup_session_send_message (session, msg);
+  stream = soup_session_send (session, msg, NULL, &error);
+  status_code = soup_message_get_status (msg);
 
-  if (!SOUP_STATUS_IS_SUCCESSFUL (msg->status_code))
+  if (error || !SOUP_STATUS_IS_SUCCESSFUL (status_code))
     {
+      g_autofree gchar *message = NULL;
+
+      if (error)
+        {
+          message = error->message;
+          g_clear_error (&error);
+        }
+      else
+        {
+          message = g_strdup (soup_message_get_reason_phrase (msg));
+        }
+
       dialog = gtk_message_dialog_new (GTK_WINDOW (priv->main_window),
                                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                                        GTK_MESSAGE_WARNING,
                                        GTK_BUTTONS_CLOSE,
                                        "Error loading module info: %s",
-                                       soup_status_get_phrase (msg->status_code));
-      gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
+                                       message);
+      g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+      gtk_window_present (GTK_WINDOW (dialog));
       return;
     }
 
   parser = json_parser_new ();
 
   /* Load response body and fill branches and domains, then show widgets */
-  json_parser_load_from_data (parser, msg->response_body->data, msg->response_body->length, &error);
+  json_parser_load_from_stream (parser, stream, NULL, &error);
   node = json_parser_get_root (parser);
 
   object = json_node_get_object(node);
@@ -295,8 +308,8 @@ gtr_dl_teams_parse_modules_json (GObject *object,
                                              GTK_BUTTONS_CLOSE,
                                              "%s",
                                              error->message);
-      gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
+      g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+      gtk_window_present (GTK_WINDOW (dialog));
       return;
     }
 
@@ -318,12 +331,12 @@ gtr_dl_teams_load_json (GtrDlTeams *self)
   /* Get team list JSON from DL */
   g_autoptr(SoupSession) session = soup_session_new ();
   g_autoptr(SoupMessage) message = soup_message_new ("GET", g_strconcat ((const gchar *)API_URL, "teams", NULL));
-  soup_session_send_async (session, message, NULL, gtr_dl_teams_parse_teams_json, self);
+  soup_session_send_async (session, message, G_PRIORITY_DEFAULT, NULL, gtr_dl_teams_parse_teams_json, self);
 
   /* Get module list JSON from DL */
   g_autoptr(SoupSession) session_modules = soup_session_new ();
   g_autoptr(SoupMessage) message_modules = soup_message_new ("GET", g_strconcat ((const gchar *)API_URL, "modules", NULL));
-  soup_session_send_async (session_modules, message_modules, NULL, gtr_dl_teams_parse_modules_json, self);
+  soup_session_send_async (session_modules, message_modules, G_PRIORITY_DEFAULT, NULL, gtr_dl_teams_parse_modules_json, self);
 }
 
 void gtr_dl_teams_verify_and_load (GtrDlTeams *self)
@@ -352,7 +365,7 @@ gtr_dl_teams_get_file_info (GtrDlTeams *self)
   gchar *stats_endpoint;
   JsonNode *node = NULL;
   g_autoptr(JsonParser) parser = NULL;
-  g_autoptr(JsonObject) object = NULL;
+  JsonObject *object;
   SoupMessage *msg;
   SoupSession *session;
   GError *error = NULL;
@@ -362,6 +375,8 @@ gtr_dl_teams_get_file_info (GtrDlTeams *self)
   char *markup;
   g_autofree char *module_state = NULL;
   GtkWidget *dialog;
+  SoupStatus status_code;
+  g_autoptr(GInputStream) stream = NULL;
 
   /* API endpoint: modules/[module]/branches/[branch]/domains/[domain]/languages/[team] */
   stats_endpoint = g_strconcat ((const gchar *)API_URL,
@@ -377,25 +392,38 @@ gtr_dl_teams_get_file_info (GtrDlTeams *self)
 
   msg = soup_message_new ("GET", stats_endpoint);
   session = soup_session_new ();
-  soup_session_send_message (session, msg);
+  stream = soup_session_send (session, msg, NULL, &error);
+  status_code = soup_message_get_status (msg);
 
-  if (!SOUP_STATUS_IS_SUCCESSFUL (msg->status_code))
+  if (error || !SOUP_STATUS_IS_SUCCESSFUL (status_code))
     {
+      g_autofree gchar *message = NULL;
+
+      if (error)
+        {
+          message = error->message;
+          g_clear_error (&error);
+        }
+      else
+        {
+          message = g_strdup (soup_message_get_reason_phrase (msg));
+        }
+
       dialog = gtk_message_dialog_new (GTK_WINDOW (priv->main_window),
                                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                                        GTK_MESSAGE_WARNING,
                                        GTK_BUTTONS_CLOSE,
                                        "Error loading file info: %s",
-                                       soup_status_get_phrase (msg->status_code));
-      gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
+                                       message);
+      g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+      gtk_window_present (GTK_WINDOW (dialog));
       return;
     }
 
   parser = json_parser_new ();
 
   /* Load response body and get path to PO file */
-  json_parser_load_from_data (parser, msg->response_body->data, msg->response_body->length, &error);
+  json_parser_load_from_stream (parser, stream, NULL, &error);
   node = json_parser_get_root (parser);
 
   object = json_node_get_object(node);
@@ -464,16 +492,16 @@ gtr_dl_teams_load_po_file (GtkButton *button, GtrDlTeams *self)
   GFile *tmp_file = NULL;
   GFileIOStream *iostream = NULL;
   GOutputStream *output = NULL;
-  gsize bytes = 0;
   GtkWidget *dialog;
   gboolean ret = FALSE;
   int file_index = 0;
   const char *dest_dir = g_get_user_special_dir (G_USER_DIRECTORY_DOWNLOAD);
   g_autofree char *basename = NULL;
-  g_autofree char *filename = NULL;
   g_autofree char *file_path = NULL;
   g_autoptr(GFile) dest_file = NULL;
   gboolean reserve_first = FALSE;
+  SoupStatus status_code;
+  GBytes *bytes;
 
   // reserve for translation first
   reserve_first = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
@@ -494,19 +522,32 @@ gtr_dl_teams_load_po_file (GtkButton *button, GtrDlTeams *self)
 
   /* Load the file, save as temp; path to file is https://l10n.gnome.org/[priv->file_path] */
   session = soup_session_new ();
-  msg = soup_message_new ("GET", g_strconcat ("https://l10n.gnome.org", g_strcompress(priv->file_path), NULL));
-  soup_session_send_message (session, msg);
+  msg = soup_message_new ("GET", g_strconcat (DL_SERVER, g_strcompress(priv->file_path), NULL));
+  bytes = soup_session_send_and_read (session, msg, NULL, &error);
+  status_code = soup_message_get_status (msg);
 
-  if (!SOUP_STATUS_IS_SUCCESSFUL (msg->status_code))
+  if (error || !SOUP_STATUS_IS_SUCCESSFUL (status_code))
     {
+      g_autofree gchar *message = NULL;
+
+      if (error)
+        {
+          message = error->message;
+          g_clear_error (&error);
+        }
+      else
+        {
+          message = g_strdup (soup_message_get_reason_phrase (msg));
+        }
+
       dialog = gtk_message_dialog_new (GTK_WINDOW (priv->main_window),
                                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                                        GTK_MESSAGE_WARNING,
                                        GTK_BUTTONS_CLOSE,
                                        "Error loading file: %s",
-                                       soup_status_get_phrase (msg->status_code));
-      gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
+                                       message);
+      g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+      gtk_window_present (GTK_WINDOW (dialog));
       return;
     }
 
@@ -520,19 +561,18 @@ gtr_dl_teams_load_po_file (GtkButton *button, GtrDlTeams *self)
                                        GTK_BUTTONS_CLOSE,
                                        "Error creating temp file: %s",
                                        error->message);
-      gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
+      g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+      gtk_window_present (GTK_WINDOW (dialog));
       g_error_free (error);
       return;
     }
 
   output = g_io_stream_get_output_stream (G_IO_STREAM (iostream));
-  g_output_stream_write_all (output,
-                             msg->response_body->data,
-                             msg->response_body->length,
-                             &bytes,
-                             NULL,
-                             &error);
+  g_output_stream_write_bytes (output,
+                               bytes,
+                               NULL,
+                               &error);
+  g_bytes_unref (bytes);
 
   if (error != NULL)
     {
@@ -549,16 +589,13 @@ gtr_dl_teams_load_po_file (GtkButton *button, GtrDlTeams *self)
   /* Save file to Downloads; file basename is the part from last / character on */
   basename = g_path_get_basename (priv->file_path);
   // Remove the extension
-  filename = g_strdup_printf ("%s.%s.%s", priv->selected_module, priv->selected_branch, basename);
-  g_free (basename);
-  basename = g_strdup (filename);
   file_path = g_strconcat ("file://", dest_dir, "/", basename, NULL);
   dest_file = g_file_new_for_uri (file_path);
 
   ret = g_file_copy (tmp_file, dest_file, G_FILE_COPY_NONE, NULL, NULL, NULL, &error);
   while (!ret && g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
     {
-      g_autofree char *tmpname = gtr_utils_get_filename (filename);
+      g_autofree char *tmpname = gtr_utils_get_filename (basename);
       g_free (basename);
       g_free (file_path);
       g_object_unref (dest_file);
@@ -617,6 +654,9 @@ gtr_dl_teams_reserve_for_translation (GtkWidget *button, GtrDlTeams *self)
   const char *auth_token = NULL;
   g_autofree char *auth = NULL;
   g_autofree gchar *reserve_endpoint = NULL;
+  SoupStatus status_code;
+  g_autoptr(GInputStream) stream = NULL;
+  GError *error = NULL;
 
   pmanager = gtr_profile_manager_get_default ();
   profile = gtr_profile_manager_get_active_profile (pmanager);
@@ -633,12 +673,26 @@ gtr_dl_teams_reserve_for_translation (GtkWidget *button, GtrDlTeams *self)
 
   msg = soup_message_new ("POST", reserve_endpoint);
   soup_message_set_flags (msg, SOUP_MESSAGE_NO_REDIRECT);
-  soup_message_headers_append (msg->request_headers, "Authentication", auth);
+  soup_message_headers_append (soup_message_get_request_headers (msg),
+                               "Authentication", auth);
   session = soup_session_new ();
-  soup_session_send_message (session, msg);
+  stream = soup_session_send (session, msg, NULL, &error);
+  status_code = soup_message_get_status (msg);
 
-  if (!SOUP_STATUS_IS_SUCCESSFUL (msg->status_code))
+  if (error || !SOUP_STATUS_IS_SUCCESSFUL (status_code))
   {
+    g_autofree gchar *message = NULL;
+
+    if (error)
+      {
+        message = error->message;
+        g_clear_error (&error);
+      }
+    else
+      {
+        message = g_strdup (soup_message_get_reason_phrase (msg));
+      }
+
     dialog = gtk_message_dialog_new_with_markup (
       GTK_WINDOW (priv->main_window),
       GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -650,9 +704,10 @@ gtr_dl_teams_reserve_for_translation (GtkWidget *button, GtrDlTeams *self)
         "<b>token</b> correctly in your profile or you don't have "
         "permissions to reserve this module."
       ),
-      soup_status_get_phrase (msg->status_code));
-    gtk_dialog_run (GTK_DIALOG (dialog));
-    gtk_widget_destroy (dialog);
+      message);
+    g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+    gtk_window_present (GTK_WINDOW (dialog));
+
     return FALSE;
   }
 
@@ -667,8 +722,8 @@ gtr_dl_teams_reserve_for_translation (GtkWidget *button, GtrDlTeams *self)
                                            priv->selected_team,
                                            priv->selected_domain);
 
-  gtk_dialog_run (GTK_DIALOG (success_dialog));
-  gtk_widget_destroy (success_dialog);
+  g_signal_connect (success_dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+  gtk_window_present (GTK_WINDOW (success_dialog));
   gtk_widget_set_sensitive (priv->reserve_button, FALSE);
 
   return TRUE;
@@ -813,14 +868,14 @@ gtr_dl_teams_init (GtrDlTeams *self)
   gtk_widget_set_name (priv->teams_combobox, "combo_teams");
   gtr_filter_selection_set_text (GTR_FILTER_SELECTION (priv->teams_combobox), _("Translation Team"));
 
-  gtk_container_add (GTK_CONTAINER (priv->select_box), priv->teams_combobox);
+  gtk_box_append (GTK_BOX (priv->select_box), priv->teams_combobox);
   gtk_widget_set_sensitive (priv->teams_combobox, FALSE);
 
   priv->modules_combobox = GTK_WIDGET (gtr_filter_selection_new ());
   gtk_widget_set_name (priv->modules_combobox, "combo_modules");
   gtr_filter_selection_set_text (GTR_FILTER_SELECTION (priv->modules_combobox), _("Module"));
 
-  gtk_container_add (GTK_CONTAINER (priv->select_box), priv->modules_combobox);
+  gtk_box_append (GTK_BOX (priv->select_box), priv->modules_combobox);
   gtk_widget_set_sensitive (priv->modules_combobox, FALSE);
 
   g_signal_connect (priv->open_button,
@@ -831,12 +886,12 @@ gtr_dl_teams_init (GtrDlTeams *self)
   /* Add empty combo boxes for DL domains and branches and hide them */
   priv->domains_combobox = gtk_combo_box_text_new ();
   gtk_widget_set_name (priv->domains_combobox, "combo_domains");
-  gtk_container_add (GTK_CONTAINER (priv->select_box), priv->domains_combobox);
+  gtk_box_append (GTK_BOX (priv->select_box), priv->domains_combobox);
   gtk_widget_hide (priv->domains_combobox);
 
   priv->branches_combobox = gtk_combo_box_text_new ();
   gtk_widget_set_name (priv->branches_combobox, "combo_branches");
-  gtk_container_add (GTK_CONTAINER (priv->select_box), priv->branches_combobox);
+  gtk_box_append (GTK_BOX (priv->select_box), priv->branches_combobox);
   gtk_widget_hide (priv->branches_combobox);
 
   /* Load teams and modules automatically */
@@ -891,7 +946,7 @@ team_add_cb (GtkButton   *btn,
 {
   GtrDlTeamsPrivate *priv = gtr_dl_teams_get_instance_private (self);
   GtrWindow *window = GTR_WINDOW (priv->main_window);
-  gtr_open_file_dialog (NULL, window);
+  gtr_open_file_dialog (window);
 }
 
 
