@@ -50,7 +50,7 @@ struct _GtrHeader
   GtrMsg parent_instance;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (GtrHeader, gtr_header, GTR_TYPE_MSG)
+G_DEFINE_FINAL_TYPE_WITH_PRIVATE (GtrHeader, gtr_header, GTR_TYPE_MSG)
 
 static void
 gtr_header_set_field (GtrHeader * header,
@@ -785,7 +785,14 @@ update_comments (GtrHeader *header, const gchar *comments)
 
           year_array = g_strsplit (comment_lines[i], ",", -1);
 
-          for (j = 1; year_array != NULL && year_array[j] != NULL; j++)
+          // Empty comment
+          if (year_array == NULL || year_array[0] == NULL)
+            {
+              g_strfreev (year_array);
+              continue;
+            }
+
+          for (j = 1; year_array[j] != NULL; j++)
             {
               gchar *search;
 
