@@ -40,6 +40,7 @@
 #include "gtr-profile.h"
 #include "gtr-utils.h"
 #include "gtr-message-container.h"
+#include "gtr-preferences-dialog.h"
 
 #include <string.h>
 #include <errno.h>
@@ -76,6 +77,9 @@ typedef struct
   /* The obsolete messages are stored within this gchar. */
   gchar *obsolete;
 
+  /* Whether po file contains obsolete entries or not */
+  gboolean po_contains_obsolete_entries;
+
   /* Is the file write-permitted? (read-only) */
   gboolean no_write_perms;
 
@@ -113,10 +117,10 @@ typedef struct
 } GtrPoPrivate;
 
 
-G_DEFINE_TYPE_WITH_CODE (GtrPo, gtr_po, G_TYPE_OBJECT,
-                         G_ADD_PRIVATE (GtrPo)
-                         G_IMPLEMENT_INTERFACE (GTR_TYPE_MESSAGE_CONTAINER,
-                                                gtr_po_message_container_init))
+G_DEFINE_FINAL_TYPE_WITH_CODE (GtrPo, gtr_po, G_TYPE_OBJECT,
+                               G_ADD_PRIVATE (GtrPo)
+                               G_IMPLEMENT_INTERFACE (GTR_TYPE_MESSAGE_CONTAINER,
+                                                      gtr_po_message_container_init))
 
 enum
 {
@@ -214,6 +218,7 @@ gtr_po_init (GtrPo * po)
 {
   GtrPoPrivate *priv = gtr_po_get_instance_private (po);
 
+  priv->po_contains_obsolete_entries = FALSE;
   priv->location = NULL;
   priv->gettext_po_file = NULL;
   priv->dl_team = NULL;
@@ -526,30 +531,20 @@ _gtr_po_load (GtrPo * po, GFile * location, GError ** error)
 static gboolean
 _gtr_po_load_ensure_utf8 (GtrPo * po, GError ** error)
 {
-  GMappedFile *mapped;
-  const gchar *content;
+  g_autofree gchar *content = NULL;
   gboolean utf8_valid;
-  gchar *filename;
   gsize size;
+  g_autoptr (GError) err = NULL;
   GtrPoPrivate *priv = gtr_po_get_instance_private (po);
 
-  filename = g_file_get_path (priv->location);
-  mapped = g_mapped_file_new (filename, FALSE, error);
-  g_free (filename);
-
-  if (!mapped)
+  g_file_load_contents (priv->location, NULL, &content, &size, NULL, &err);
+  if (err != NULL)
     return FALSE;
 
-  content = g_mapped_file_get_contents (mapped);
-  size = g_mapped_file_get_length (mapped);
-
   utf8_valid = g_utf8_validate (content, size, NULL);
 
   if (!_gtr_po_load (po, priv->location, error))
-    {
-      g_mapped_file_unref (mapped);
-      return FALSE;
-    }
+    return FALSE;
 
   if (!utf8_valid &&
       priv->header)
@@ -576,7 +571,6 @@ _gtr_po_load_ensure_utf8 (GtrPo * po, GError ** error)
                            GTR_PO_ERROR_ENCODING,
                            _("Could not convert from charset “%s” to UTF-8"),
                            charset);
-              g_mapped_file_unref (mapped);
               g_free (charset);
               return FALSE;
             }
@@ -593,7 +587,6 @@ _gtr_po_load_ensure_utf8 (GtrPo * po, GError ** error)
                            GTR_PO_ERROR_ENCODING,
                            _("Could not store temporary "
                              "file for encoding conversion"));
-              g_mapped_file_unref (mapped);
               g_object_unref (converter);
               return FALSE;
             }
@@ -616,7 +609,6 @@ _gtr_po_load_ensure_utf8 (GtrPo * po, GError ** error)
               g_object_unref (converter_stream);
               g_object_unref (iostream);
               g_object_unref (converter);
-              g_mapped_file_unref (mapped);
               return FALSE;
             }
 
@@ -626,10 +618,7 @@ _gtr_po_load_ensure_utf8 (GtrPo * po, GError ** error)
 
           /* Now load again the converted file */
           if (!_gtr_po_load (po, tmp, error))
-            {
-              g_mapped_file_unref (mapped);
-              return FALSE;
-            }
+            return FALSE;
 
           /* Ensure Content-Type is set correctly
            * in the header as per the content
@@ -641,8 +630,6 @@ _gtr_po_load_ensure_utf8 (GtrPo * po, GError ** error)
         }
     }
 
-  g_mapped_file_unref (mapped);
-
   if (!utf8_valid)
     {
       g_set_error (error,
@@ -752,6 +739,8 @@ gtr_po_parse (GtrPo * po, GFile * location, GError ** error)
           /* Build up messages */
           priv->messages = g_list_prepend (priv->messages, msg);
         }
+      else
+        priv->po_contains_obsolete_entries = TRUE;
     }
 
   if (priv->messages == NULL)
@@ -796,6 +785,9 @@ gtr_po_save_file (GtrPo * po, GError ** error)
   gchar *msg_error;
   GtrHeader *header;
   GtrPoPrivate *priv = gtr_po_get_instance_private (po);
+  /* can't use priv->iter as its already exhausted*/
+  po_message_iterator_t iter = po_message_iterator (priv->gettext_po_file, NULL);
+  po_message_t message;
 
   /*
    * Initialice the handler error.
@@ -819,6 +811,21 @@ gtr_po_save_file (GtrPo * po, GError ** error)
       return;
     }
 
+  /*
+   * Removes obsolete entries from file if user opt for it
+   */
+  if (priv->po_contains_obsolete_entries && gtr_prefs_get_remove_obsolete ())
+    {
+      while ((message = po_next_message (iter)))
+        {
+          if(po_message_is_obsolete (message))
+            {
+              po_message_set_msgstr (message,"");
+              po_message_set_msgid (message, "");
+            }
+        }
+    }
+
 
   if (is_read_only (filename))
     {
