@@ -55,6 +55,7 @@ typedef struct
 
   /* Files->General */
   GtkWidget *warn_if_contains_fuzzy_checkbutton;
+  GtkCheckButton *remove_obsolete_entries;
 
   /* Files->Autosave */
   GtkWidget *autosave_checkbutton;
@@ -100,6 +101,11 @@ setup_files_general_page (GtrPreferencesDialog * dlg)
                    priv->warn_if_contains_fuzzy_checkbutton,
                    "active",
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+  g_settings_bind (priv->files_settings,
+                   GTR_SETTINGS_REMOVE_OBSOLETE_ENTRIES,
+                   priv->remove_obsolete_entries,
+                   "active",
+                   G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
 }
 
 static void
@@ -143,6 +149,14 @@ setup_files_autosave_page (GtrPreferencesDialog * dlg)
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
 }
 
+int 
+gtr_prefs_get_remove_obsolete ()
+{
+  GSettings *files_settings = g_settings_new ("org.gnome.gtranslator.preferences.files");
+  gboolean remove_obsolete_entries_bool = g_settings_get_boolean (files_settings, GTR_SETTINGS_REMOVE_OBSOLETE_ENTRIES);
+  return remove_obsolete_entries_bool;
+}
+
 static void
 setup_files_pages (GtrPreferencesDialog * dlg)
 {
@@ -427,8 +441,8 @@ delete_button_clicked (GtkWidget *button, GtrPreferencesDialog *dlg)
                                                     (dialog),
                                                     _("Another profile should be selected as active before"));
 
-          gtk_dialog_run (GTK_DIALOG (dialog));
-          gtk_widget_destroy (dialog);
+          g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+          gtk_window_present (GTK_WINDOW (dialog));
         }
       else
         {
@@ -448,10 +462,9 @@ delete_button_clicked (GtkWidget *button, GtrPreferencesDialog *dlg)
           gtk_dialog_add_button (GTK_DIALOG (dialog),
                                  _("_Delete"), GTK_RESPONSE_YES);
 
-          gtk_dialog_run (GTK_DIALOG (dialog));
-
           g_signal_connect (GTK_DIALOG (dialog), "response",
                             G_CALLBACK (delete_confirm_dialog_cb), dlg);
+          gtk_window_present (GTK_WINDOW (dialog));
         }
     }
 }
@@ -657,9 +670,11 @@ gtr_preferences_dialog_init (GtrPreferencesDialog * dlg)
 
   content_area = GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg)));
 
-  /* HIG defaults */
-  gtk_container_set_border_width (GTK_CONTAINER (dlg), 5);
-  gtk_box_set_spacing (content_area, 2);    /* 2 * 5 + 2 = 12 */
+  gtk_widget_set_margin_start (GTK_WIDGET (dlg), 6);
+  gtk_widget_set_margin_end (GTK_WIDGET (dlg), 6);
+  gtk_widget_set_margin_top (GTK_WIDGET (dlg), 6);
+  gtk_widget_set_margin_bottom (GTK_WIDGET (dlg), 6);
+  gtk_box_set_spacing (content_area, 6);
 
   g_signal_connect (dlg,
                     "response", G_CALLBACK (dialog_response_handler), NULL);
@@ -670,6 +685,7 @@ gtr_preferences_dialog_init (GtrPreferencesDialog * dlg)
   priv->notebook = GTK_WIDGET (gtk_builder_get_object (builder, "notebook"));
   g_object_ref (priv->notebook);
   priv->warn_if_contains_fuzzy_checkbutton = GTK_WIDGET (gtk_builder_get_object (builder, "warn_if_fuzzy_checkbutton"));
+  priv->remove_obsolete_entries = GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "remove_obsolete_entries"));
   priv->autosave_checkbutton = GTK_WIDGET (gtk_builder_get_object (builder, "autosave_checkbutton"));
   priv->autosave_interval_spinbutton = GTK_WIDGET (gtk_builder_get_object (builder, "autosave_interval_spinbutton"));
   priv->autosave_grid = GTK_WIDGET (gtk_builder_get_object (builder, "autosave_grid"));
@@ -687,9 +703,12 @@ gtr_preferences_dialog_init (GtrPreferencesDialog * dlg)
   profiles_scrolled_window = GTK_WIDGET (gtk_builder_get_object (builder, "profiles-scrolledwindow"));
   g_object_unref (builder);
 
-  gtk_box_pack_start (content_area, priv->notebook, FALSE, FALSE, 0);
+  gtk_box_append (content_area, priv->notebook);
 
-  gtk_container_set_border_width (GTK_CONTAINER (priv->notebook), 5);
+  gtk_widget_set_margin_start (priv->notebook, 6);
+  gtk_widget_set_margin_end (priv->notebook, 6);
+  gtk_widget_set_margin_top (priv->notebook, 6);
+  gtk_widget_set_margin_bottom (priv->notebook, 6);
 
   context = gtk_widget_get_style_context (profiles_scrolled_window);
   gtk_style_context_set_junction_sides (context, GTK_JUNCTION_BOTTOM);
@@ -753,4 +772,3 @@ gtr_show_preferences_dialog (GtrWindow * window)
 
   gtk_window_present (GTK_WINDOW (dlg));
 }
-
