@@ -120,7 +120,7 @@ project_add_cb (GtkButton   *btn,
 {
   GtrProjectsPrivate *priv = gtr_projects_get_instance_private (self);
   GtrWindow *window = GTR_WINDOW (priv->main_window);
-  gtr_open_file_dialog (NULL, window);
+  gtr_open_file_dialog (window);
 }
 
 static void
