@@ -19,14 +19,13 @@
 
 #pragma once
 
-#include <dazzle.h>
 #include <gtksourceview/gtksource.h>
 
 G_BEGIN_DECLS
 
 #define GTR_TYPE_SEARCH_BAR (gtr_search_bar_get_type())
 
-G_DECLARE_FINAL_TYPE (GtrSearchBar, gtr_search_bar, GTR, SEARCH_BAR, DzlBin)
+G_DECLARE_FINAL_TYPE (GtrSearchBar, gtr_search_bar, GTR, SEARCH_BAR, GtkBin)
 
 enum
 {
