@@ -47,6 +47,7 @@
 #include "gtr-window.h"
 #include "gtr-progress.h"
 #include "gtr-actions.h"
+#include "gtr-utils.h"
 
 #include <glib.h>
 #include <glib-object.h>
@@ -167,6 +168,20 @@ gtr_page_stop_search (GtrTab *tab,
 
 }
 
+void
+gtr_tab_focus_search_bar (GtrTab *tab)
+{
+  GtrTabPrivate *priv;
+  GtkEntry *entry;
+
+  g_assert (GTR_IS_TAB (tab));
+  priv = gtr_tab_get_instance_private (tab);
+
+  entry = (GtkEntry *) gtr_search_bar_get_search (priv->search_bar);
+
+  gtk_entry_grab_focus_without_selecting (entry);
+}
+
 void
 gtr_tab_show_hide_search_bar (GtrTab *tab, gboolean show)
 {
@@ -246,15 +261,6 @@ show_hide_revealer (GtkWidget *widget, GdkEvent *ev, GtrTab *tab)
   return TRUE;
 }
 
-static gboolean
-msg_grab_focus (GtrTab *tab)
-{
-  GtrTabPrivate *priv;
-  priv = gtr_tab_get_instance_private (tab);
-  gtk_widget_grab_focus (priv->trans_msgstr[0]);
-  return FALSE;
-}
-
 static void
 install_autosave_timeout (GtrTab * tab)
 {
@@ -786,7 +792,7 @@ gtr_tab_init (GtrTab * tab)
   priv->find_replace_flag = FALSE;
   priv->progress = gtr_progress_new ();
   gtk_widget_show (GTK_WIDGET (priv->progress));
-  gtk_container_add (GTK_CONTAINER (priv->progress_box), GTK_WIDGET (priv->progress));
+  gtk_box_append (GTK_BOX (priv->progress_box), GTK_WIDGET (priv->progress));
 
   g_signal_connect (priv->progress_eventbox, "button-press-event",
                     G_CALLBACK (show_hide_revealer), tab);
@@ -1244,11 +1250,6 @@ gtr_tab_message_go_to (GtrTab * tab,
   else
     return;
 
-  // Grabbing the focus in the GtrView to edit the message
-  // This is done in the idle add to avoid the focus grab from the
-  // message-table
-  g_idle_add((GSourceFunc)msg_grab_focus, tab);
-
   /*
    * Emitting showed-message signal
    */
@@ -1922,7 +1923,7 @@ gtr_tab_set_info_bar (GtrTab * tab, GtkWidget * infobar)
   if (infobar == NULL)
     return;
 
-  gtk_box_pack_start (GTK_BOX (tab), priv->infobar, FALSE, FALSE, 0);
+  gtk_box_append (GTK_BOX (tab), priv->infobar);
 
   g_object_add_weak_pointer (G_OBJECT (priv->infobar),
                              (gpointer *) & priv->infobar);
