@@ -40,7 +40,6 @@
 #include <gtk/gtk.h>
 
 #include <gtksourceview/gtksource.h>
-#include <dazzle.h>
 
 #include <gspell/gspell.h>
 
@@ -172,7 +171,7 @@ gtr_view_dispose (GObject * object)
   g_clear_object (&priv->editor_settings);
   g_clear_object (&priv->ui_settings);
   g_clear_object (&priv->spell);
-  g_object_unref (&priv->provider);
+  g_clear_object (&priv->provider);
 
   G_OBJECT_CLASS (gtr_view_parent_class)->dispose (object);
 }
@@ -919,12 +918,12 @@ gtr_view_set_font (GtrView *view, char *font)
   g_autofree char *str = NULL;
   g_autofree char *css = NULL;
   GtrViewPrivate *priv = gtr_view_get_instance_private (view);
-  g_autoptr (GtkWidget) button = gtk_font_button_new ();
+  GtkWidget *button = gtk_font_button_new ();
 
   gtk_font_chooser_set_font (GTK_FONT_CHOOSER (button), font);
   font_desc = gtk_font_chooser_get_font_desc (GTK_FONT_CHOOSER (button));
-  str = dzl_pango_font_description_to_css (font_desc);
-  css = g_strdup_printf ("textview { %s }", str ?: "");
+  str = pango_font_description_to_css (font_desc);
+  css = g_strdup_printf ("textview  %s", str ?: "");
 
   gtk_css_provider_load_from_data (priv->provider, css, -1, NULL);
 
