@@ -93,7 +93,7 @@ typedef struct
   guint dispose_has_run : 1;
 } GtrWindowPrivate;
 
-G_DEFINE_TYPE_WITH_PRIVATE(GtrWindow, gtr_window, GTK_TYPE_APPLICATION_WINDOW)
+G_DEFINE_FINAL_TYPE_WITH_PRIVATE(GtrWindow, gtr_window, GTK_TYPE_APPLICATION_WINDOW)
 
 enum
 {
@@ -528,6 +528,16 @@ gtr_window_create_tab (GtrWindow * window, GtrPo * po)
   GtrWindowPrivate *priv = gtr_window_get_instance_private(window);
   GtrTab *tab;
 
+  // Remove all tabs when creating a new one,
+  // this way we only have one tab. This is a workaround
+  // to remove the tab functionality without change all
+  // the code
+  GList *tabs, *l;
+  tabs = gtr_window_get_all_tabs (window);
+  for (l = tabs; l != NULL; l = g_list_next (l))
+    _gtr_window_close_tab (window, l->data);
+  g_list_free (tabs);
+
   tab = gtr_tab_new (po, GTK_WINDOW (window));
   gtk_widget_show (GTK_WIDGET (tab));
 
@@ -817,22 +827,12 @@ void
 gtr_window_show_tm_dialog (GtrWindow *window)
 {
   GtrWindowPrivate *priv = gtr_window_get_instance_private(window);
-  static GtkWidget *dlg = NULL;
+  GtkWidget *dlg;
 
-  if (dlg == NULL)
-    {
-      dlg = gtr_translation_memory_dialog_new (priv->translation_memory);
-      gtk_window_set_transient_for (GTK_WINDOW (dlg), GTK_WINDOW (window));
+  dlg = gtr_translation_memory_dialog_new (GTK_WINDOW (window),
+                                           priv->translation_memory);
 
-      g_signal_connect (dlg, "destroy",
-                        G_CALLBACK (gtk_widget_destroyed), &dlg);
-      gtk_widget_show_all (dlg);
-    }
-
-  if (GTK_WINDOW (window) != gtk_window_get_transient_for (GTK_WINDOW (dlg)))
-    {
-      gtk_window_set_transient_for (GTK_WINDOW (dlg), GTK_WINDOW (window));
-    }
+  g_signal_connect (dlg, "response", G_CALLBACK (gtk_widget_destroy), NULL);
 
   gtk_window_present (GTK_WINDOW (dlg));
 }
@@ -921,12 +921,29 @@ gtr_window_show_search_bar (GtrWindow *window,
   GtrNotebook *notebook = GTR_NOTEBOOK (priv->notebook);
   GtrTab *tab = gtr_window_get_active_tab (window);
 
-  gtr_tab_show_hide_search_bar (tab, show);
+  if (tab != NULL)
+    gtr_tab_show_hide_search_bar (tab, show);
+
   gtr_notebook_enable_find_button(notebook, show);
 
   priv->search_bar_shown = show;
 }
 
+// Shortcut for find now calls this
+void
+gtr_window_show_focus_search_bar (GtrWindow *window,
+                                  gboolean show)
+{
+  GtrWindowPrivate *priv = gtr_window_get_instance_private (window);
+  GtrTab *tab = gtr_window_get_active_tab (window);
+
+  // don't need to show if already shown but need to focus on entry
+  if (tab != NULL && priv->search_bar_shown == show)
+    gtr_tab_focus_search_bar (tab);
+  else
+    gtr_window_show_search_bar (window, show);
+}
+
 void
 gtr_window_toggle_search_bar (GtrWindow *window)
 {
