@@ -35,14 +35,8 @@
 G_BEGIN_DECLS
 
 #define GTR_TYPE_WINDOW		(gtr_window_get_type ())
-#define GTR_WINDOW(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_WINDOW, GtrWindow))
-#define GTR_WINDOW_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_WINDOW, GtrWindowClass))
-#define GTR_IS_WINDOW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_WINDOW))
-#define GTR_IS_WINDOW_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), GTR_TYPE_WINDOW))
-#define GTR_WINDOW_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GTR_TYPE_WINDOW, GtrWindowClass))
 
-typedef struct _GtrWindow        GtrWindow;
-typedef struct _GtrWindowClass   GtrWindowClass;
+G_DECLARE_FINAL_TYPE (GtrWindow, gtr_window, GTR, WINDOW, GtkApplicationWindow)
 
 struct _GtrWindow
 {
@@ -54,10 +48,6 @@ struct _GtrWindowClass
   GtkApplicationWindowClass parent_class;
 };
 
-GType gtr_window_get_type (void) G_GNUC_CONST;
-
-GType gtr_window_register_type (GTypeModule * module);
-
 GtrTab *gtr_window_create_tab (GtrWindow * window, GtrPo * po);
 
 GtrTab *gtr_window_get_active_tab (GtrWindow * window);
@@ -90,7 +80,7 @@ void gtr_window_tm_keybind (GtrWindow *window, GSimpleAction *action);
 
 void gtr_window_hide_sort_menu (GtrWindow *window);
 
-void gtr_window_show_search_bar (GtrWindow *window, gboolean show);
+void gtr_window_show_focus_search_bar (GtrWindow *window, gboolean show);
 void gtr_window_toggle_search_bar (GtrWindow *window);
 
 /** stack app states **/
