@@ -19,6 +19,7 @@
 #include "gtr-profile-manager.h"
 #include "gtr-translation-memory-utils.h"
 #include "gtr-po.h"
+#include "gtr-utils.h"
 
 #include <glib/gi18n.h>
 
@@ -39,6 +40,31 @@ typedef struct
 
 G_DEFINE_TYPE_WITH_PRIVATE (GtrTranslationMemoryDialog, gtr_translation_memory_dialog, GTK_TYPE_DIALOG)
 
+static void
+native_response_cb (GtkNativeDialog *dialog, guint response, gpointer user_data)
+{
+  GtrTranslationMemoryDialog *dlg;
+  GtrTranslationMemoryDialogPrivate *priv;
+
+  dlg = GTR_TRANSLATION_MEMORY_DIALOG (user_data);
+  priv = gtr_translation_memory_dialog_get_instance_private (dlg);
+
+  if (response == GTK_RESPONSE_ACCEPT)
+    {
+      g_autofree char *filename = NULL;
+      GtkFileChooser *chooser = GTK_FILE_CHOOSER (dialog);
+
+      filename = gtk_file_chooser_get_filename (chooser);
+      gtk_entry_set_text (GTK_ENTRY (priv->directory_entry),
+                          filename);
+      g_settings_set_string (priv->tm_settings,
+                             "po-directory",
+                             filename);
+    }
+
+  gtk_native_dialog_destroy (dialog);
+}
+
 static void
 gtr_translation_memory_dialog_finalize (GObject *object)
 {
@@ -71,8 +97,6 @@ on_search_button_clicked (GtkButton                  *button,
                           GtrTranslationMemoryDialog *dlg)
 {
   GtkFileChooserNative *native;
-  gint res;
-  GtrTranslationMemoryDialogPrivate *priv = gtr_translation_memory_dialog_get_instance_private (dlg);
 
   native = gtk_file_chooser_native_new (_("Select PO directory"),
                                         GTK_WINDOW (dlg),
@@ -80,22 +104,8 @@ on_search_button_clicked (GtkButton                  *button,
                                         _("_OK"),
                                         _("_Cancel"));
 
-  res = gtk_native_dialog_run (GTK_NATIVE_DIALOG (native));
-  if (res == GTK_RESPONSE_ACCEPT)
-    {
-      char *filename;
-      GtkFileChooser *chooser = GTK_FILE_CHOOSER (native);
-
-      filename = gtk_file_chooser_get_filename (chooser);
-      gtk_entry_set_text (GTK_ENTRY (priv->directory_entry),
-                          filename);
-      g_settings_set_string (priv->tm_settings,
-                             "po-directory",
-                             filename);
-      g_free (filename);
-    }
-
-  g_object_unref (native);
+  g_signal_connect (native, "response", G_CALLBACK (native_response_cb), dlg);
+  gtk_native_dialog_show (GTK_NATIVE_DIALOG (native));
 }
 
 typedef struct _IdleData
@@ -103,7 +113,6 @@ typedef struct _IdleData
   GSList *list;
   GtkProgressBar *progress;
   GtrTranslationMemory *tm;
-  GtkWindow *parent;
   GtkWidget *add_database_button;
 } IdleData;
 
@@ -124,7 +133,7 @@ add_to_database (gpointer data_pointer)
       GList *msg_list = NULL;
       GFile *location;
       GError *error = NULL;
-      GtrPo *po;
+      g_autoptr(GtrPo) po = NULL;
 
       po = gtr_po_new ();
       location = (GFile *) l->data;
@@ -136,8 +145,6 @@ add_to_database (gpointer data_pointer)
       msg_list = gtr_po_get_messages (po);
 
       gtr_translation_memory_store_list (data->tm, msg_list);
-
-      g_object_unref (po);
     }
   else
     {
@@ -227,7 +234,6 @@ launch_gtr_scan_dir_task (GtrTranslationMemoryDialog *dlg,
   idata->list = NULL;
   idata->tm = priv->translation_memory;
   idata->progress = GTK_PROGRESS_BAR (priv->add_database_progressbar);
-  idata->parent = GTK_WINDOW (dlg);
   idata->add_database_button = priv->add_database_button;
 
   gtk_progress_bar_pulse (idata->progress);
@@ -306,13 +312,6 @@ gtr_translation_memory_dialog_init (GtrTranslationMemoryDialog *dlg)
 
   content_area = gtk_dialog_get_content_area (GTK_DIALOG (dlg));
 
-  /* HIG defaults */
-  gtk_container_set_border_width (GTK_CONTAINER (dlg), 5);
-  gtk_box_set_spacing (GTK_BOX (content_area), 2);    /* 2 * 5 + 2 = 12 */
-
-  g_signal_connect (dlg, "response",
-                    G_CALLBACK (gtk_widget_destroy), NULL);
-
   builder = gtk_builder_new ();
   gtk_builder_add_objects_from_resource (builder, "/org/gnome/gtranslator/plugins/translation-memory/ui/gtr-translation-memory-dialog.ui", root_objects, NULL);
   content = GTK_WIDGET (gtk_builder_get_object (builder, "translation-memory-box"));
@@ -325,7 +324,8 @@ gtr_translation_memory_dialog_init (GtrTranslationMemoryDialog *dlg)
   priv->tm_lang_entry = GTK_WIDGET (gtk_builder_get_object (builder, "tm-lang-entry"));
   g_object_unref (builder);
 
-  gtk_box_pack_start (GTK_BOX (content_area), content, TRUE, TRUE, 0);
+  gtk_widget_set_vexpand (content, TRUE);
+  gtk_box_append (GTK_BOX (content_area), content);
   g_object_unref (content);
 
   prof_manager = gtr_profile_manager_get_default ();
@@ -371,20 +371,21 @@ gtr_translation_memory_dialog_init (GtrTranslationMemoryDialog *dlg)
 }
 
 GtkWidget *
-gtr_translation_memory_dialog_new (GtrTranslationMemory *translation_memory)
+gtr_translation_memory_dialog_new (GtkWindow *window,
+                                   GtrTranslationMemory *translation_memory)
 {
   GtrTranslationMemoryDialog *dlg;
   GtrTranslationMemoryDialogPrivate *priv;
 
   dlg = GTR_TRANSLATION_MEMORY_DIALOG (g_object_new (GTR_TYPE_TRANSLATION_MEMORY_DIALOG,
-                                                     "use-header-bar", TRUE, NULL));
+                                                     "use-header-bar", TRUE,
+                                                     "modal", TRUE,
+                                                     "transient-for", window,
+                                                     NULL));
   priv = gtr_translation_memory_dialog_get_instance_private (dlg);
 
   /* FIXME: use a property */
   priv->translation_memory = translation_memory;
 
-  gtk_window_set_type_hint (GTK_WINDOW (dlg), GDK_WINDOW_TYPE_HINT_DIALOG);
-  gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
-
   return GTK_WIDGET (dlg);
 }
